@@ -22,10 +22,11 @@ class ThemedWidget(ABC, tk.Widget):
         "highlightcolor"
     }
 
-    def __init__(self, master, widget_name: str = None):
+    def __init__(self, master=None, widget_name: str = None):
         if widget_name is None:
             widget_name = self.__class__.__name__.lower()
-        tk.Widget.__init__(self, master, widget_name)
+        if master is not None:
+            tk.Widget.__init__(self, master, widget_name)
         self.__updated_kwargs = {}
 
     def update_color_in_kwargs(self, kw_in: Dict[str, Union[str, int]]) -> Dict[str, Union[str, int]]:
@@ -54,11 +55,11 @@ class ThemedWidget(ABC, tk.Widget):
 
 
 class ThemedWindow(ThemedWidget, tk.Wm):
-
     def __init__(self):
+        ThemedWidget.__init__(self)
         self.__theme_updated_id = None
         self.bind('<Configure>', self.on_configure)
-        self.after(10, self.update_theme)
+        self.after(50, self.update_theme)
 
     def center(self):
         self.after(10, self.__move_to_center_of_screen)
@@ -77,11 +78,15 @@ class ThemedWindow(ThemedWidget, tk.Wm):
             self.__theme_updated_id = self.after(500, self.update_theme)
 
     def update_theme(self):
-        self.config(bg=self.get_color('main_bg'))
-        for child in self.children.values():
-            if isinstance(child, ThemedWidget):
-                child.update_theme()
-        self.__theme_updated_id = None
+        try:
+            self.config(bg=self.get_color('main_bg'))
+            for child in self.children.values():
+                if isinstance(child, ThemedWidget):
+                    child.update_theme()
+        except tk.TclError:
+            pass
+        finally:
+            self.__theme_updated_id = None
 
     @property
     def frame_size(self):
