@@ -4,4 +4,4 @@ from .frame import Frame
 from .label import Label
 from .text import Text, ScrollableText
 from .tk import Tk
-from .top_level import TopLevel
+from .top_level import Toplevel
