@@ -8,7 +8,7 @@ from .frame import Frame
 class Button(tk.Button, ThemedWidget):
     def __init__(self, master, **kwargs):
         self.border_frame = Frame(master)
-        ThemedWidget.__init__(self, master, 'button')
+        ThemedWidget.__init__(self)
         kwargs = self.update_color_in_kwargs(kwargs)
         self.border_width = kwargs.get('bd', 3)
         kwargs['bd'] = 0
