@@ -10,7 +10,7 @@ class Entry(tk.Entry, ThemedWidget):
         self.border_width = kwargs.get('bd', 1)
         kwargs['bd'] = 0
         kwargs.setdefault('font', 'themed_default')
-        ThemedWidget.__init__(self, master, 'entry')
+        ThemedWidget.__init__(self)
         tk.Entry.__init__(self, self.border_frame, **kwargs)
 
     def update_theme(self):
