@@ -5,7 +5,7 @@ from ..abs_class import ThemedWidget
 
 class Frame(tk.Frame, ThemedWidget):
     def __init__(self, master, **kwargs):
-        ThemedWidget.__init__(self, master)
+        ThemedWidget.__init__(self)
         kwargs = self.update_color_in_kwargs(kwargs)
         tk.Frame.__init__(self, master, **kwargs)
 
