@@ -7,7 +7,7 @@ from .frame import Frame
 class Text(tk.Text, ThemedWidget):
     def __init__(self, master, **kwargs):
         self.border_frame = Frame(master)
-        ThemedWidget.__init__(self, master)
+        ThemedWidget.__init__(self)
         kwargs = self.update_color_in_kwargs(kwargs)
         self.border_width = kwargs.get('bd', 1)
         kwargs['bd'] = 0
@@ -27,7 +27,7 @@ class Text(tk.Text, ThemedWidget):
 
 class ScrollableText(tk.Frame, ThemedWidget):
     def __init__(self, master, **kwargs):
-        ThemedWidget.__init__(self, master, 'frame')
+        ThemedWidget.__init__(self)
         kwargs['bd'] = 1
         tk.Frame.__init__(self, master, **kwargs)
 
