@@ -5,7 +5,7 @@ from enum import Enum
 from typing import Union
 
 
-from ..abs_class import ThemedWindow
+from ..abs_class import ThemedWidget, ThemedWindow
 from ..font import build_all_font
 from ..color import add_tk_instance
 
@@ -18,12 +18,13 @@ class Theme(Enum):
 
 class Tk(tk.Tk, ThemedWindow):
     def __init__(self):
-        tk.Tk.__init__(self)
-        ThemedWindow.__init__(self)
         self.__theme = None
         self.__theme_forced = Theme.AUTO
+        tk.Tk.__init__(self)
+        ThemedWindow.__init__(self)
         build_all_font(self)
         add_tk_instance(self)
+        self.update_theme()
 
     @property
     def theme(self):
@@ -39,6 +40,8 @@ class Tk(tk.Tk, ThemedWindow):
             new_theme = new_theme.value
         if new_theme.lower() in [e.value for e in Theme]:
             self.__theme_forced = new_theme
+            self.__theme = None
+            self.update_theme()
         else:
             raise RuntimeError("Wrong theme")
 
