@@ -1,8 +1,8 @@
 import tkinter as tk
-from ..abs_class import ThemedWindow
+from ..abs_class import ThemedWidget, ThemedWindow
 
 
-class TopLevel(tk.Toplevel, ThemedWindow):
+class Toplevel(tk.Toplevel, ThemedWindow):
     def __init__(self, master, **kw):
         tk.Toplevel.__init__(self, master, **kw)
         ThemedWindow.__init__(self)
@@ -10,8 +10,9 @@ class TopLevel(tk.Toplevel, ThemedWindow):
         self.focus()
         # Disable the calling window until we are done
         # `grab_release()` isn't necessary. Control is automatically released when toplevels are closed
-        self.grab_set()
+        #self.grab_set()
         self.after(10, self.__move_to_center_of_parent_win)
+        self.update_theme()
 
     def __move_to_center_of_parent_win(self):
         self.update_idletasks()
